---
name: Refactoring suggestion
about: Suggest a way to improve CAREamics' codebase
title: "[Refactoring]"
labels: refactoring
assignees: ''
---

## Description
<!-- A description of the current pain points. -->

[description here]

### Which part of the code?

- [links to code]

### Examples

``` python
# [example of the pain points and their consequences]
```

## Potential solutions

<!-- Describe potential solutions in different sections. -->

### [Name of Solution 1]

<!-- A description of a potential solution. -->

``` python
# [suggested change to code for Solution 1]
```

## References

<!-- Add any other context, links to other codebase, PEP, best practices, etc. that could help understand or validate the solution -->

[additional context here]
